==> haskell-fingertree-0.1.4.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.4.1
id: fingertree-0.1.4.1-4dGWAkLOsb9H06SZoMljo2
key: fingertree-0.1.4.1-4dGWAkLOsb9H06SZoMljo2
license: BSD-3-Clause
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
abi: d82f2b67c18acea46461391a0331eade
exposed: True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
import-dirs: /usr/lib/ghc-8.6.2/site-local/fingertree-0.1.4.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/fingertree-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/fingertree-0.1.4.1
hs-libraries: HSfingertree-0.1.4.1-4dGWAkLOsb9H06SZoMljo2
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fingertree-0.1.4.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.4.2
id: fingertree-0.1.4.2-9GfNn90LrWwLpCJ2A4ySYJ
key: fingertree-0.1.4.2-9GfNn90LrWwLpCJ2A4ySYJ
license: BSD-3-Clause
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
abi: 4e0fb01eb41078cdcda6f6dc6fb0a6fb
exposed: True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
import-dirs: /usr/lib/ghc-8.6.3/site-local/fingertree-0.1.4.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/fingertree-0.1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/fingertree-0.1.4.2
hs-libraries: HSfingertree-0.1.4.2-9GfNn90LrWwLpCJ2A4ySYJ
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
